function [M_RD_N] = MRD_tramyPole_02(i_tr,Pole,DelkaPole,iPrutu,Fyd,h)
%Stanovení momentu únosnosti dle skutečného vyztužení
% Pro tramy v poli
% i_tr      cislo tramu, ktery ted pocitame
% pole      urceni zda se jedna o krajni pole, vnitrni pole nebo pole nad
%           podporou
% delkaPole  delak pole v mm, lisi se dle prurezu
%iPrutu     pocet prutu v kazdem prurezu ([dolni vrstva, druha vrstva,
%           treti vrstva]
% Fyd       MPa navrhova mez kluzu
% h         mm vyska jednotlivych tramu v kazde podpore
%v01 - chybne stanoveni momentu unosnosti Mrd - chybne uvazovana vyska tlacene oblasti
%v02 - nova funkce pro stanoveni momentu unosnosti Mrd - spravne stanoveni
%POZOR - NUTNO VYBRAT PRUMER VYZTUZE 

i=iPrutu;


c=20;%mm kryti vyztuze
d_tr=5;%mm prumer trminku


switch i_tr  %plati pouze v poli, nad podporou je to jinak
    case 1
%         h=1280;%mm vyska tramu -------------------funkci tramu i
        b1=1200;            %zleva
        b2=(1500-300)/2;    %zprava        
%         dle dokumentace
        d_s=20;%mm prumer hlavni vyztuze
        %vyhovi
%         d_s=30;%mm prumer hlavni vyztuze
        s_c=30;%mm svetla vzdalenost mezi pruty ve vrstvach

    case 2
%         h=1280;%mm vyska tramu -------------------funkci tramu i
        b1=(1500-300)/2;    %zleva
        b2=(1500-300)/2;    %zprava
%       dle dokumentace
        d_s=20;%mm prumer hlavni vyztuze
        %vyhovi
%         d_s=30;%mm prumer hlavni vyztuze
        s_c=30;%mm svetla vzdalenost mezi pruty ve vrstvach
    case 3
%         h=1280;%mm vyska tramu -------------------funkci tramu i
        b1=(1500-300)/2;    %zleva
        b2=(1500-300)/2;    %zprava
        %dle dokumentace
        d_s=20;%mm prumer hlavni vyztuze
        %vyhovi
%         d_s=30;%mm prumer hlavni vyztuze
        s_c=30;%mm svetla vzdalenost mezi pruty ve vrstvach

    case 4
%         h=1000;%mm vyska tramu -------------------funkci tramu i
        b1=(1500-300)/2;    %zleva
        b2=(1500-300)/2;    %zprava
        d_s=30;%mm prumer hlavni vyztuze
        s_c=45;%mm svetla vzdalenost mezi pruty ve vrstvach

    case 5
%         h=1000;%mm vyska tramu -------------------funkci tramu i
        b1=(1500-300)/2;    %zleva
        b2=(1800);          %zprava
        d_s=30;%mm prumer hlavni vyztuze
        s_c=45;%mm svetla vzdalenost mezi pruty ve vrstvach

end

%urceni ucinne vysky
switch size(i,2)
    case 2
        d(1)=h-c-d_tr-d_s/2;
        d(2)=h-c-d_tr-d_s-s_c-d_s/2;
    case 3
        d(1)=h-c-d_tr-d_s/2;
        d(2)=h-c-d_tr-d_s-s_c-d_s/2;
        d(3)=h-c-d_tr-2*d_s-2*s_c-d_s/2;%ucinna vyska
end

As=i*(pi*d_s^2)/4;%mm^2 plochy vyztuze jednotlivych vrstev

fck=12;%Mpa
fcd=fck/1.5;%navrhova pevnost v tlaku

% urceni b_eff
bT=300;%mm stejne pro vsechny tramy

switch Pole
    case 'krajni'
%         beff	=	bT	+	beff,1	+	beff,2	=	2100	mm 
        L0=0.85*DelkaPole;%mm
        beff_1=min([0.2*b1+0.1*L0,0.2*L0,b1]);%mm
        beff_2=min([0.2*b2+0.1*L0,0.2*L0,b2]);%mm
        beffc=	bT	+	beff_1	+	beff_2;%mm
%         disp('krajni')
    case 'vnitrni'
%         disp('vnitrni')
        L0=0.7*DelkaPole;%mm
        beff_1=min([0.2*b1+0.1*L0,0.2*L0,b1]);%mm
        beff_2=min([0.2*b2+0.1*L0,0.2*L0,b2]);%mm
        beffc=	bT	+	beff_1	+	beff_2;%mm
    case 'podpora'
%         disp('podpora')
        %zatim nepouzito
end
% výška tlačené oblast x=
x=sum(As)*Fyd/(0.8*beffc*fcd);%Vyska_tl_obl
%rameno vnitrnich sil
z=d-0.4*x;%ramena vnitrnich sil
M_RD_N=Fyd*As*z';%N*mm
M_RD_N=M_RD_N*1e-6;%kN*m
        
end

